dtcm_insert(1)

dtcm_insert - insert appointments into the calendar database

As shipped in IRIX 6.5.30. Added in IRIX 6.5.19.

     NAME
          dtcm_insert - insert appointments into the calendar database

     SYNOPSIS
          dtcm_insert [-c calendar] [-d date] [-s start] [-e end]
          [-v view] [-w what]

     DESCRIPTION
          The dtcm_insert utility is non-GUI interface to the CDE
          calendar and appointment services, used to add new
          appointments to the calendar database via the RPC daemon
          rpc.cmsd(1).  Appointments are added one at a time.  Each of
          the components of an appointment is specified using one of
          the command-line options.  Once an appointment is added, the
          list of appointments for the specified date (see the -d and
          -v options) is displayed.

     OPTIONS
          The following options are available:

             -c calendar
                   Specify the name of the target calendar.  Calendar
                   names typically take the form user@hostname, where
                   user is a user's login name and hostname is the
                   host machine name.  An example is felix@cat.  If no
                   target calendar is specified, the calendar defaults
                   to the current user at the current host machine.

             -d date
                   Specify the date for the appointment(s) to be
                   inserted.  The date is specified using the form
                   mm/dd/yy, where mm, dd and yy are the two-digit
                   month, day and year modulo 100, respectively.
                   Certain other references such as ``today,''
                   ``Tuesday,'' ``tomorrow,'' etc.  are correctly
                   calculated.  If no date is specified, date defaults
                   to today's date.

             -s start
                   Specify the starting time for the appointment.  The
                   time is specified using the form hh:mm.  If hh is
                   greater than 12, 24-hour convention (for example,
                   15:30 instead of 3:30 pm ) is assumed.  If hh is 0
                   to 12, an optional am or pm suffix can be used,
                   with or without white space separating the suffix
                   from the mm.  If no suffix is used, am is assumed.
                   If no starting time is specified, no time is
                   associated with the inserted appointment.

             -e end
                   The ending time for the appointment, in the same
                   format as -s.  Specifying an ending time without a

                   starting time is an error.

             -v view
                   Specify the view span of appointments to display.
                   The view option-argument can be:

                      day       Display all appointments for the given
                                date (see -d option).

                      week      Display the full week that contains
                                the given date, starting with Sunday.

                      month     Display the entire month that contains
                                the given date.

             -w what
                   Specify the appointment description text.  Up to 5
                   lines of text can be specified by placing \n (the
                   literal characters \ and n, not <newline>) between
                   lines.  If not specified, what defaults to
                   Appointment.

     OPERANDS
          None.

     STDIN
          Not used.

     INPUT FILES
          None.

     ENVIRONMENT VARIABLES
          The following environment variables affect the execution of
          dtcm_insert:

             LANG           Provide a default value for the
                            internationalization variables that are
                            unset or null.  If LANG is unset or null,
                            the corresponding value from the
                            implementation-specific default locale
                            will be used.  If any of the
                            internationalization variables contains an
                            invalid setting, the utility behaves as if
                            none of the variables had been defined.

             LC_ALL         If set to a non-empty string value,
                            override the values of all the other
                            internationalization variables.

             LC_MESSAGES    Determine the locale that is used to
                            affect the format and contents of
                            diagnostic messages written to standard

                            error and informative messages written to
                            standard output.

             NLSPATH        Determine the location of message
                            catalogues for the processing of
                            LC_MESSAGES.

     RESOURCES
          None.

     ASYNCHRONOUS EVENTS
          The dtcm_insert utility takes the standard action for all
          signals.

     STDOUT
          The standard output contains the list of appointments for
          the specified view span, including the appointment just
          inserted.

     STDERR
          Used only for diagnostic messages.

     OUTPUT FILES
          None.

     EXTENDED DESCRIPTION
          None.

     EXIT STATUS
          The following exit values are returned:

              0  Successful completion.

             >0  An error occurred.

     CONSEQUENCES OF ERRORS
          Default.

     FILES
          /usr/spool/calendar/callog.username

          /usr/dt/bin/rpc.cmsd

     APPLICATION USAGE
          In the -w option, it may be necessary to escape the \
          character (``\\n'') or enclose the string in quotes to avoid
          interpretation by the shell.

     EXAMPLES
          The simplest form of dtcm_insert has no arguments, where the
          user is prompted to enter the appointment, line-by-line:

               dtcm_insert
               Please enter the information for the appointment you wish to add.
               Defaults will be shown in parentheses.
               Calendar (hlj@poobah):
               Date (2/27/1995):
               Start (0822): 1200
               End (1300):
               Repeat (One Time):
               What (you may enter up to 5 lines, use ^D to finish):
               lunch with the calendar team
               at Sparcy's
               ^D

               Appointments for Monday February 27, 1995:
                     1) 1200-   1300 lunch with the calendar team
                                        at Sparcy's

          To insert at a specific time:

               dtcm_insert -s "11:00 am"
               Appointments for Tuesday September 25, 1990:
                       1) Appointment

                       2) 11:00am-12:00pm Appointment

          To insert at a specific start and end time:

               dtcm_insert -s "11:00 am" -e 11:28am
               Appointments for Tuesday September 25, 1990:
                       1) Appointment
                       2) 11:00am-11:28am Appointment

          To insert at a specific time and date:

               dtcm_insert -s 11:00am -d 09/26/90
               Appointments for Wednesday September 26, 1990:
                       1) 11:00am-12:00pm Appointment

          To insert at a specific time, date, and message:

               dtcm_insert -s "11:00 am" -d 09/26/90 -w "call home"
               Appointments for Wednesday September 26, 1990:
                       1) 11:00am-12:00pm Appointment
                       2) 11:00am-12:00pm call home

          To insert a multiple-line appointment:

               dtcm_insert -s 12:00 -w "call dentist\n
                                no thanks\ncancel appointment"
               Appointments for Tuesday September 25, 1990:
                       1) Appointment

                       2) 11:00am-12:00pm Appointment
                       3) 12:00pm-1:00pm call dentist
                                no thanks
                                cancel appointment

     SEE ALSO
          rpc.cmsd(1), dtcm(1), dtcm_admin(1), dtcm_delete(1),
          dtcm_lookup(1).